model saclay

global {
	file shape_file_buildings <- file("../includes/osm_polygon.shp");
	file shape_file_roads <- file("../includes/osm_line.shp");
	file shape_file_bounds <- file("../includes/osm_point.shp");
	geometry shape <- envelope(shape_file_bounds);
	list<building> gares;
	list<building> bat_univ;
	float step <- 10 #mn;
	int nb_people <- 100;
	
	init {
		create building from: shape_file_buildings with: [type::string(read ("building")), amenity::string(read ("amenity"))] {
			if (type!="yes" and type!="station") {
//				write("kill "+self.name);
				do die;
			}
			if name contains "Bâtiment"
			{
				color<-#blue;
			}
			if name!=""
			{
				color<-#blue;
			}
		}
		create road from: shape_file_roads with: [type::string(read ("highway"))] {
			color<-#blue;
			if type=""
			{
				write("kill "+self.name);
				do die;
			}
			if type="footway" {
				color <- #green ;
			}
		}

		gares <- building where (each.color=#red);
		bat_univ <- building where (each.color=#blue);

		create people number: nb_people {
			location <- any_location_in (one_of (bat_univ));
		}
	}
}

species building {
	string type; 
	rgb color <- #gray  ;
	
	aspect base {
		draw shape color: color ;
	}
}

species road  {
	string type;
	rgb color <- #black ;
	aspect base {
		draw shape color: color ;
	}
}

species people {
	rgb color <- #yellow ;
	
	aspect base {
		draw circle(10) color: color;
	}
}


experiment saclay type: gui {
	parameter "Shapefile for the buildings:" var: shape_file_buildings category: "GIS" ;
	parameter "Shapefile for the roads:" var: shape_file_roads category: "GIS" ;
	parameter "Shapefile for the bounds:" var: shape_file_bounds category: "GIS" ;
	parameter "Number of people agents" var: nb_people category: "People" ;
	
	output {
		display city_display type:opengl {
			species building aspect: base ;
			species road aspect: base ;
			species people aspect: base ;
		}
	}
}